==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/mp1287_001/MP1287_Store2StoreTransfer_001.java <==

package net.datastream.schemas.mp_functions.mp1287_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.store2storetransfer_001.Store2StoreTransfer;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/Store2StoreTransfer_001}Store2StoreTransfer"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Transfer" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="Store2Store" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="Store2StoreTransfer" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "store2StoreTransfer"
})
@XmlRootElement(name = "MP1287_Store2StoreTransfer_001")
public class MP1287_Store2StoreTransfer_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "Store2StoreTransfer", namespace = "http://schemas.datastream.net/MP_entities/Store2StoreTransfer_001", required = true)
    protected Store2StoreTransfer store2StoreTransfer;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;

    /**
     * Gets the value of the store2StoreTransfer property.
     * 
     * @return
     *     possible object is
     *     {@link Store2StoreTransfer }
     *     
     */
    public Store2StoreTransfer getStore2StoreTransfer() {
        return store2StoreTransfer;
    }

    /**
     * Sets the value of the store2StoreTransfer property.
     * 
     * @param value
     *     allowed object is
     *     {@link Store2StoreTransfer }
     *     
     */
    public void setStore2StoreTransfer(Store2StoreTransfer value) {
        this.store2StoreTransfer = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.TRANSFER;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.STORE_2_STORE;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the callname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "Store2StoreTransfer";
        } else {
            return callname;
        }
    }

    /**
     * Sets the value of the callname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp1287_001/MP1287_Store2StoreTransfer_001.java <==

package net.datastream.schemas.mp_functions.mp1287_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.store2storetransfer_001.Store2StoreTransfer;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_entities/Store2StoreTransfer_001}Store2StoreTransfer"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Transfer" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="Store2Store" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       <attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="Store2StoreTransfer" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "store2StoreTransfer"
})
@XmlRootElement(name = "MP1287_Store2StoreTransfer_001")
public class MP1287_Store2StoreTransfer_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "Store2StoreTransfer", namespace = "http://schemas.datastream.net/MP_entities/Store2StoreTransfer_001", required = true)
    protected Store2StoreTransfer store2StoreTransfer;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;

    /**
     * Gets the value of the store2StoreTransfer property.
     * 
     * @return
     *     possible object is
     *     {@link Store2StoreTransfer }
     *     
     */
    public Store2StoreTransfer getStore2StoreTransfer() {
        return store2StoreTransfer;
    }

    /**
     * Sets the value of the store2StoreTransfer property.
     * 
     * @param value
     *     allowed object is
     *     {@link Store2StoreTransfer }
     *     
     */
    public void setStore2StoreTransfer(Store2StoreTransfer value) {
        this.store2StoreTransfer = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.TRANSFER;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.STORE_2_STORE;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the callname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "Store2StoreTransfer";
        } else {
            return callname;
        }
    }

    /**
     * Sets the value of the callname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

}
